@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0700';
+our $VERSION = '0.0800';
 
 use v5.36;
 
@@ -13,7 +13,7 @@ use IO::Async::Timer::Periodic ();
 use Iterator::Breathe ();
 use Moo;
 use Types::MIDI qw(Channel Velocity);
-use Types::Common::Numeric qw(PositiveNum);
+use Types::Common::Numeric qw(NegativeNum PositiveNum);
 use Types::Standard qw(Bool Num Maybe);
 use namespace::clean;
 
@@ -76,7 +76,7 @@ has range_top => (
 
 has range_step => (
     is      => 'rw',
-    isa     => PositiveNum,
+    isa     => NegativeNum | PositiveNum,
     default => 1,
 );
 
@@ -111,8 +111,7 @@ has running => (
 
 sub single ($self, $device, $dt, $event) {
     my ($ev, $chan, $note, $val) = $event->@*;
-    return 0 if $self->trigger && $note != $self->trigger;
-    return 0 if $self->value && $val != $self->value;
+    return 0 if defined $self->trigger && $note != $self->trigger;
 
     my $cc = [ 'control_change', $self->channel, $self->control, $self->value ];
     $self->rtc->send_it($cc);
@@ -124,8 +123,8 @@ sub breathe ($self, $device, $dt, $event) {
     return 0 if $self->running;
 
     my ($ev, $chan, $note, $val) = $event->@*;
-    return 0 if $self->trigger && $note != $self->trigger;
-    return 0 if $self->value && $val != $self->value;
+    return 0 if defined $self->trigger && $note != $self->trigger;
+    return 0 if defined $self->value && $val != $self->value;
 
     $self->running(1);
 
@@ -154,8 +153,8 @@ sub scatter ($self, $device, $dt, $event) {
     return 0 if $self->running;
 
     my ($ev, $chan, $note, $val) = $event->@*;
-    return 0 if $self->trigger && $note != $self->trigger;
-    return 0 if $self->value && $val != $self->value;
+    return 0 if defined $self->trigger && $note != $self->trigger;
+    return 0 if defined $self->value && $val != $self->value;
 
     $self->running(1);
 
@@ -181,8 +180,8 @@ sub stair_step ($self, $device, $dt, $event) {
     return 0 if $self->running;
 
     my ($ev, $chan, $note, $val) = $event->@*;
-    return 0 if $self->trigger && $note != $self->trigger;
-    return 0 if $self->value && $val != $self->value;
+    return 0 if defined $self->trigger && $note != $self->trigger;
+    return 0 if defined $self->value && $val != $self->value;
 
     $self->running(1);
 
@@ -224,12 +223,12 @@ sub stair_step ($self, $device, $dt, $event) {
 }
 
 
-sub ramp ($self, $device, $dt, $event) {
+sub ramp_up ($self, $device, $dt, $event) {
     return 0 if $self->running;
 
     my ($ev, $chan, $note, $val) = $event->@*;
-    return 0 if $self->trigger && $note != $self->trigger;
-    return 0 if $self->value && $val != $self->value;
+    return 0 if defined $self->trigger && $note != $self->trigger;
+    return 0 if defined $self->value && $val != $self->value;
 
     $self->running(1);
 
@@ -260,6 +259,43 @@ sub ramp ($self, $device, $dt, $event) {
     return 0;
 }
 
+
+sub ramp_down ($self, $device, $dt, $event) {
+    return 0 if $self->running;
+
+    my ($ev, $chan, $note, $val) = $event->@*;
+    return 0 if defined $self->trigger && $note != $self->trigger;
+    return 0 if defined $self->value && $val != $self->value;
+
+    $self->running(1);
+
+    my $value = $self->initial_point;
+
+    $self->rtc->loop->add(
+        IO::Async::Timer::Countdown->new(
+            delay     => $self->time_step,
+            on_expire => sub {
+                my $c = shift;
+
+                my $cc = [ 'control_change', $self->channel, $self->control, $value ];
+                $self->rtc->send_it($cc);
+
+                $value -= $self->range_step;
+
+                if ($value < $self->range_bottom) {
+                    $c->stop;
+                    $self->running(0);
+                }
+                else {
+                    $c->start;
+                }
+            },
+        )->start
+    );
+
+    return 0;
+}
+
 1;
 
 __END__
@@ -274,7 +310,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0700
+version 0.0800
 
 =head1 SYNOPSIS
 
@@ -356,9 +392,9 @@ Default: C<1> (mod-wheel)
   $value = $filter->value;
   $filter->value($number);
 
-Return or set the control change value. This is a generic setting that
-can be used by filters to set or retrieve state. This often a whole
-number between C<0> and C<127>, but can take any number.
+Return or set the MIDI event value. This is a generic setting that can
+be used by filters to set or retrieve state. This often a whole number
+between C<0> and C<127>, but can take any number.
 
 Default: C<undef>
 
@@ -462,9 +498,8 @@ Return a new C<MIDI::RtController::Filter::CC> object.
 This filter sets a single B<control> change message, over the MIDI
 B<channel> once.
 
-If B<trigger> or B<value> is set, the filter checks those against the
-MIDI event C<note> or C<value>, respectively, to see if the filter
-should be applied.
+If B<trigger> is set, the filter checks that against the MIDI event
+C<note> to see if the filter should be applied.
 
 =head2 breathe
 
@@ -509,13 +544,23 @@ If B<trigger> or B<value> is set, the filter checks those against the
 MIDI event C<note> or C<value>, respectively, to see if the filter
 should be applied.
 
-=head2 ramp
+=head2 ramp_up
 
-  $control->add_filter('ramp', all => $filter->curry::ramp);
+  $control->add_filter('ramp_up', all => $filter->curry::ramp_up);
 
-This filter ramps-up (or down) a B<control> change message, over the
-MIDI B<channel>, from B<range_bottom> until the B<range_top> is
-reached.
+This filter ramps-up a B<control> change message, over the MIDI
+B<channel>, from B<range_bottom> until the B<range_top> is reached.
+
+If B<trigger> or B<value> is set, the filter checks those against the
+MIDI event C<note> or C<value>, respectively, to see if the filter
+should be applied.
+
+=head2 ramp_down
+
+  $control->add_filter('ramp_down', all => $filter->curry::ramp_down);
+
+This filter ramps-down a B<control> change message, over the MIDI
+B<channel>, from B<range_top> until the B<range_bottom> is reached.
 
 If B<trigger> or B<value> is set, the filter checks those against the
 MIDI event C<note> or C<value>, respectively, to see if the filter
